@@ -25,18 +25,13 @@ pfcoMod <- function(fcMat, samp, log2.opt=0, trim.opt=0.25) {
        idx <- deb:fin;
        m2 <- length(idx);
        rvect <- c(rmat.s[,1:m]);
-       rvect2 <- c(rep(0, n*m2));
-       rmat.val <- rmatTrim(rvect, n, m, idx, m2, rvect2);
-       rmat.sr <- matrix(rmat.val$rvect2, ncol = m2);
-       rvect <- rmat.val$rvect2;
-       moyV <- c(rep(0,n));
-       stdV <- c(rep(0,n));
-       rmat.val <- moyStdCalc(rvect, n, m2, moyV, stdV);
+       rvect2 <- rmatTrim(rvect, n, m, idx, m2);
+       rmat.sr <- matrix(rvect2, ncol = m2);
+       rvect <- rvect2;
+       rmat.val <- moyStdCalc(rvect, n, m2);
        moyV <- rmat.val$moyC;
        stdV <- rmat.val$stdC;
-       FC2 <- c(rep(0,n));
-       rmat.val <- fc2Calc(rvectFC, n, m, idx, m2, FC2)
-       FC2 <- rmat.val$fc2C;
+       FC2 <- fc2Calc(rvectFC, n, m, idx, m2)
        rm(rvect);
        rm(rmat.val);
        rm(rvectFC);
@@ -46,14 +41,10 @@ pfcoMod <- function(fcMat, samp, log2.opt=0, trim.opt=0.25) {
          m2 <- m;
          idx <- 1:m2;
          rvect <- c(rmat.sr[,1:m2]);
-         moyV <- c(rep(0,n));
-         stdV <- c(rep(0,n));
-         rmat.val <- moyStdCalc(rvect, n, m2, moyV, stdV);
+         rmat.val <- moyStdCalc(rvect, n, m2);
          moyV <- rmat.val$moyC;
          stdV <- rmat.val$stdC;
-         FC2 <- c(rep(0,n));
-         rmat.val <- fc2Calc(rvectFC, n, m, idx, m2, FC2)
-         FC2 <- rmat.val$fc2C;
+         FC2 <- fc2Calc(rvectFC, n, m, idx, m2)
          rm(rvect);
          rm(rmat.val);
          rm(rvectFC);
@@ -65,19 +56,18 @@ pfcoMod <- function(fcMat, samp, log2.opt=0, trim.opt=0.25) {
     v1 <- smat.eig$vectors[,1];
     if (v1[1] < 0) v1 <- -v1;
     u1 <- rmat.sr %*% v1;
+    d1 <- sqrt(n * smat.eig$values[1])
+    u1 <- u1/d1
+    u1 <- u1/max(u1)
 
     # compute probabilitie for u1 values using normal distribution
-    tt <- c(1.0, 0.9, 0.945, 0.97, 0.97, 0.97)
-    at <- floor(10*trim.opt)
-    moy <- tt[at+1] * mean(u1)
+    moy <- 0.5
     std <- sd(u1);
     f.value <- pnorm(u1, mean = moy, sd = std)
 
     # perform the Student one sample test
     em <- 0.5;
-    prob <- c(rep(0,n));
-    pval <- tprobaCalc(moyV, stdV, n, m2-1, em, prob);
-    p.value <- pval$probaC;
+    p.value <- tprobaCalc(moyV, stdV, n, m2-1, em);
 
     # decomposition parameters
     comp <- sqrt(smat.eig$values);
